@@ -975,15 +975,15 @@ display_key_press_event (GtkWidget *widget, GdkEventKey *event, gpointer data)
 	}
 
 	if (do_zoom) {
-		GdkDeviceManager *device_manager;
+		GdkSeat *seat;
 		GdkDevice *device;
 		gint x, y;
 
-		device_manager = gdk_display_get_device_manager (gtk_widget_get_display(widget));
-		device = gdk_device_manager_get_client_pointer (device_manager);
+		seat = gdk_display_get_default_seat (gtk_widget_get_display (widget));
+		device = gdk_seat_get_pointer (seat);
 
 		gdk_window_get_device_position (gtk_widget_get_window (widget), device,
-					&x, &y, NULL);
+		                                &x, &y, NULL);
 		set_zoom (view, zoom, TRUE, x, y);
 	}
 
@@ -2782,21 +2782,8 @@ eog_scroll_view_new (void)
 static void
 eog_scroll_view_popup_menu (EogScrollView *view, GdkEventButton *event)
 {
-	GtkWidget *popup;
-	int button, event_time;
-
-	popup = view->priv->menu;
-
-	if (event) {
-		button = event->button;
-		event_time = event->time;
-	} else {
-		button = 0;
-		event_time = gtk_get_current_event_time ();
-	}
-
-	gtk_menu_popup (GTK_MENU (popup), NULL, NULL, NULL, NULL,
-			button, event_time);
+	gtk_menu_popup_at_pointer (GTK_MENU (view->priv->menu),
+	                           (const GdkEvent*) event);
 }
 
 static gboolean
